@@ -4,7 +4,7 @@ namespace Fixtures\Prophecy;
 
 class WithCallableArgument
 {
-    public function methodWithArgs(callable $arg_1, callable $arg_2 = null)
+    public function methodWithArgs(callable $arg_1, ?callable $arg_2 = null)
     {
     }
 }
